NAME = "palisades"

ICON = "🧑🏽‍🚒"

DESCRIPTION = f"{ICON} Post-Disaster Land Cover Classification."

VERSION = "4.23.1"

REPO_NAME = NAME

MARQUEE = "https://github.com/kamangir/assets/blob/main/palisades/predict-datacube-maxar_open_data-WildFires-LosAngeles-Jan-2025-11-031311102213-103001010B9A1B00-2025-01-20-x54yb0/640.gif?raw=true"

ALIAS = NAME


def fullname() -> str:
    return f"{NAME}-{VERSION}"
